@@ -4,6 +4,7 @@ from itemadapter import ItemAdapter
 class BasePipeline:
     ENTITY_MAPPING = {}
     ENTITY_AUTO_SAVE = False
+    NO_AUTO_NAMES = []
 
     def __init__(self):
         self.adapter = None
@@ -16,7 +17,9 @@ class BasePipeline:
         method_name = "process_" + spider.name
         self.adapter = ItemAdapter(item)
         if self.ENTITY_AUTO_SAVE:
-            self.save_entity(item, spider)
+            if not nx.includes(self.NO_AUTO_NAMES, spider.name):
+                self.save_entity(item, spider)
+
         if hasattr(self, method_name):
             return getattr(self, method_name)(item, spider)
         return item
@@ -32,9 +35,12 @@ class BasePipeline:
         entity.save()
         return item
 
-    def fill_entity(self, **kwargs):
-        entity_class = kwargs.get('entity_class')
+    def fill_entity(self, item, spider, **kwargs):
+        spider = kwargs.get('spider')
+        mapping_class = self.ENTITY_MAPPING[spider.name]
+        entity_class = kwargs.get('entity_class', mapping_class)
         item = kwargs.get('item')
         entity = entity_class()
         entity.fill(**item)
         entity.save()
+        return item
