@@ -12,25 +12,42 @@ class BaseSpider(scrapy.Spider):
     ua_random = ua.chrome
     support_crawling = False
 
-    def get_un_crawled(self, **kwargs):
+    @classmethod
+    def is_crawled_complete(cls, **kwargs):
+        entity_class = kwargs.get('entity_class')
+        crawled = kwargs.get('crawled', {'is_crawled': False})
+        return entity_class.where(crawled).count() == 0
+
+    @classmethod
+    def get_un_crawled(cls, **kwargs):
         # required:
         entity_class = kwargs.get('entity_class')
         # crawl + optional:
         crawled = kwargs.get('crawled', {'is_crawled': False})
-        crawling_opts = {'is_crawling': True} if self.support_crawling else {}
+        crawling_opts = {'is_crawling': False} if cls.support_crawling else {}
         options = crawled.merge(kwargs.get('options', crawling_opts))
         limit = kwargs.get('limit', None)
 
         if limit:
-            return entity_class.where(options).take(limit).get()
+            records = entity_class.where(options).take(limit).get()
         else:
-            return entity_class.where(options).get()
+            records = entity_class.where(options).get()
 
-    def update_crawled(self, **kwargs):
+        # start crawling, update is_crawling
+        if cls.support_crawling:
+            for record in records:
+                record.is_crawling = True
+                record.save()
+
+        return records
+
+    @classmethod
+    def update_crawled(cls, **kwargs):
         record = kwargs.get('record')
         crawled = kwargs.get('crawled', 'is_crawled')
         setattr(record, crawled, True)
         record.save()
 
-    def noop_request(self):
+    @classmethod
+    def noop_request(cls):
         yield scrapy.Request(url="https://www.baidu.com", callback=nx.noop_scrapy_parse)
